@@ -7,12 +7,9 @@
  */
 
 #include <Python.h>
-#include <sys/sysctl.h>
+#include <sys/types.h>
 
 int _psutil_pids(pid_t **pids_array, int *pids_count);
-// TODO: refactor this. Does not belong here.
-int psutil_kinfo_proc(pid_t pid, struct kinfo_proc2 *proc);
-char *psutil_get_cmd_args(pid_t pid, size_t *argsize);
 
 PyObject *psutil_cpu_stats(PyObject *self, PyObject *args);
 PyObject *psutil_disk_io_counters(PyObject *self, PyObject *args);
