@@ -44,16 +44,11 @@ fi
 # Function to install system dependencies
 main() {
     if [ $HAS_APT ]; then
-        $SUDO apt-get update
-        $SUDO apt-get install -y python3-dev gcc
-        $SUDO apt-get install -y net-tools coreutils util-linux  # for tests
-        $SUDO apt-get install -y sudo  # for test-sudo
+        $SUDO apt-get install -y python3-dev gcc net-tools coreutils util-linux sudo
     elif [ $HAS_YUM ]; then
-        $SUDO yum install -y python3-devel gcc
-        $SUDO yum install -y net-tools coreutils util-linux  # for tests
-        $SUDO yum install -y sudo  # for test-sudo
+        $SUDO yum install -y python3-devel gcc net-tools coreutils-single util-linux sudo
     elif [ $HAS_PACMAN ]; then
-        $SUDO pacman -S --noconfirm python gcc sudo net-tools coreutils util-linux
+        $SUDO pacman -S --noconfirm python gcc net-tools coreutils util-linux sudo
     elif [ $HAS_APK ]; then
         $SUDO apk add --no-confirm python3-dev gcc musl-dev linux-headers coreutils procps
     elif [ $FREEBSD ]; then
